@@ -27,14 +27,15 @@
 
 namespace gcp {
 	
-GOColor Color = RGBA_BLACK;
-GOColor DeleteColor = RGBA_RED;
-GOColor AddColor = RGBA_GREEN;
-GOColor SelectColor = RGBA_CYAN;
+GOColor Color = GO_COLOR_BLACK;
+GOColor DeleteColor = GO_COLOR_RED;
+GOColor AddColor = GO_COLOR_GREEN;
+GOColor SelectColor = GO_COLOR_CYAN;
 unsigned MaxStackSize = 0;//infinite size authorized for undo:redo stacks
 bool MergeAtoms = true;
 int CompressionLevel = 0;
 bool TearableMendeleiev = false;
 int ClipboardFormats = GCP_CLIPBOARD_NO_TEXT;
+bool InvertWedgeHashes = false;
 
 }
